@@ -47,6 +47,7 @@ class HierarchySerializer(serializers.ModelSerializer):
     objectid = ReestrObjectsSerializer()
     parentobjid = ReestrObjectsSerializer()
     name_with_parents = serializers.SerializerMethodField()
+    has_children = serializers.SerializerMethodField()
 
     class Meta:
         model = Hierarchy
@@ -56,16 +57,33 @@ class HierarchySerializer(serializers.ModelSerializer):
         result_parts = []
         for item in obj.get_ancestors(include_self=True):
             try:
-                addr_obj = AddrObj.objects.get(objectid=item.objectid_id)
+                addr_obj = AddrObj.objects.get(
+                    objectid=item.objectid_id,
+                    isactual=True,
+                )
             except:
                 print('error')
             else:
-                result_parts.append(f'{addr_obj.name} {addr_obj.typename}')
+                type_name = addr_obj.type_full_name
+                # Если Респ, то Республика, а если г., то город
+                if addr_obj.typename and addr_obj.typename[0].islower():
+                    type_name = type_name.lower()
+
+                # Делаем так, чтобы не "область Кировская", а "Кировская область"
+                if addr_obj.is_prefix_type:
+                    addr_obj_name = f'{type_name} {addr_obj.name}'
+                else:
+                    addr_obj_name = f'{addr_obj.name} {type_name}'
+
+                result_parts.append(addr_obj_name)
 
         result = ', '.join(result_parts)
 
         return result
 
+    def get_has_children(self, obj):
+        return obj.has_children
+
 
 class MunHierarchySerializer(HierarchySerializer):
     """
